@@ -1,7 +1,34 @@
-from construct import Int8ul, Int16sl, Int16ul, Int32sl, Int32ul, Select, Struct, Switch, this, Embedded
+#
+# python-bluetooth-mesh - Bluetooth Mesh for Python
+#
+# Copyright (C) 2019  SILVAIR sp. z o.o.
+#
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#
+#
 from enum import IntEnum
+
+from construct import Embedded, Int8ul, Int16sl, Int32sl, Select, Struct, Switch, this
+
+from bluetooth_mesh.messages.generics import (
+    OptionalSetParameters,
+    TransitionTime,
+    TransitionTimeAdapter,
+)
 from bluetooth_mesh.messages.util import EnumAdapter, Opcode
-from bluetooth_mesh.messages.generics import TransitionTimeAdapter, TransitionTime, OptionalSetParameters
 
 
 class GenericLevelOpcode(IntEnum):
@@ -15,6 +42,7 @@ class GenericLevelOpcode(IntEnum):
     MOVE_SET_UNACKNOWLEDGED = 0x820C
 
 
+# fmt: off
 GenericLevelGet = Struct()
 
 GenericLevelSetMinimal = Struct(
@@ -78,7 +106,7 @@ GenericLevelStatus = Select(
 )
 
 GenericLevelMessage = Struct(
-    "opcode" / EnumAdapter(Opcode, GenericLevelOpcode),
+    "opcode" / Opcode(GenericLevelOpcode),
     "params" / Switch(
         this.opcode,
         {
@@ -93,3 +121,4 @@ GenericLevelMessage = Struct(
         },
     )
 )
+# fmt: on
